==> CLDAQ-1.14.4.tar.gz: CLDAQ/config/scripts/cldaq-setup.sh <==
# ======================================================================
#  $Id: cldaq-setup.sh,v 1.8 2004/01/29 04:48:43 goiwai Exp $
#  $Name: CLDAQ-1-14-04 $
#  $Log: cldaq-setup.sh,v $
#  Revision 1.8  2004/01/29 04:48:43  goiwai
#  CLDAQ_SHAREDLIBбͽ.
#
#  Revision 1.7  2004/01/18 21:27:00  goiwai
#  饤֥¹ԥե strip ǥե륵򾮤륪
#  ץɲäޤ.(Future Plan)
#
#  Revision 1.6  2004/01/11 13:17:11  goiwai
#  CLDAQ_SHAREDLIBɲ.
#  libCLDAQ.soбͽǤ.
#
#  Revision 1.5  2003/10/19 06:36:19  goiwai
#  ROOTȤ褦ˤ
#
#  Revision 1.4  2003/10/06 13:31:43  goiwai
#  cldaq-config
#
#  Revision 1.3  2003/08/12 11:09:14  goiwai
#  ե CLDAQ_INCLUDES, CLDAQ_LIBS ĶѿäƤޤ.
#
#  Revision 1.2  2003/07/30 16:12:50  goiwai
#  ե˥ߥåȥĤ뤳Ȥˤޤ.
#
# ======================================================================
export CLDAQ_INSTALL=$HOME/CLDAQ
export CLDAQ_CLHEP_BASE_DIR=/usr/local
export CLDAQ_CLHEP_LIB_NAME=CLHEP
export CLDAQ_ZLIB_USE=1
export CLDAQ_ROOT_USE=1
export CLDAQ_SHAREDLIB=1
export CLDAQ_STRIP=1
#
#
if test $(($CLDAQ_LIB)) -eq 1; then
    if test -n "$LD_LIBRARY_PATH"; then
	export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$CLDAQ_INSTALL/lib
    else
	export LD_LIBRARY_PATH=$CLDAQ_INSTALL/lib
    fi
fi
#
#
#export CLDAQ_INCLUDES=-I$HOME/local/include
#export CLDAQ_LIBS=-L$HOME/local/lib -lfoo -lbar -lbaz
#
#export CLDAQ_PAW_USE=1
#
#export CLDAQ_X11_USE=1
#export CLDAQ_X11_LIB_DIR=/usr/X11R6/lib
#export CLDAQ_X11_INC_DIR=/usr/X11R6/include
#export CLDAQ_GTK_USE=1
#export CLDAQ_QT_USE=1
#export CLDAQ_QT_BASE_DIR=/usr/lib/qt-2.3.1
#export CLDAQ_QT_LIB_DIR=$CLDAQ_QT_BASE_DIR/lib
#export CLDAQ_QT_INC_DIR=$CLDAQ_QT_BASE_DIR/include

==> CLDAQ-1.14.5.tar.gz: CLDAQ/config/scripts/cldaq-setup.sh <==
# ======================================================================
#  $Id: cldaq-setup.sh,v 1.9 2005/04/07 08:44:43 goiwai Exp $
#  $Name: CLDAQ-1-14-05 $
#  $Log: cldaq-setup.sh,v $
#  Revision 1.9  2005/04/07 08:44:43  goiwai
#  *** empty log message ***
#
#  Revision 1.8  2004/01/29 04:48:43  goiwai
#  CLDAQ_SHAREDLIBбͽ.
#
#  Revision 1.7  2004/01/18 21:27:00  goiwai
#  饤֥¹ԥե strip ǥե륵򾮤륪
#  ץɲäޤ.(Future Plan)
#
#  Revision 1.6  2004/01/11 13:17:11  goiwai
#  CLDAQ_SHAREDLIBɲ.
#  libCLDAQ.soбͽǤ.
#
#  Revision 1.5  2003/10/19 06:36:19  goiwai
#  ROOTȤ褦ˤ
#
#  Revision 1.4  2003/10/06 13:31:43  goiwai
#  cldaq-config
#
#  Revision 1.3  2003/08/12 11:09:14  goiwai
#  ե CLDAQ_INCLUDES, CLDAQ_LIBS ĶѿäƤޤ.
#
#  Revision 1.2  2003/07/30 16:12:50  goiwai
#  ե˥ߥåȥĤ뤳Ȥˤޤ.
#
# ======================================================================
export CLDAQ_INSTALL=$HOME/CLDAQ
export CLDAQ_CLHEP_BASE_DIR=/usr/local
export CLDAQ_CLHEP_LIB_NAME=CLHEP
#export CLDAQ_ZLIB_USE=1
#export CLDAQ_ROOT_USE=1
#export CLDAQ_SHAREDLIB=1
#export CLDAQ_STRIP=1
#
#
# if test $(($CLDAQ_SHAREDLIB)) -eq 1; then
#     if test -n "$LD_LIBRARY_PATH"; then
# 	export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$CLDAQ_INSTALL/lib
#     else
# 	export LD_LIBRARY_PATH=$CLDAQ_INSTALL/lib
#     fi
# fi
#
#
#export CLDAQ_INCLUDES=-I$HOME/local/include
#export CLDAQ_LIBS=-L$HOME/local/lib -lfoo -lbar -lbaz
#
#export CLDAQ_PAW_USE=1
#
#export CLDAQ_X11_USE=1
#export CLDAQ_X11_LIB_DIR=/usr/X11R6/lib
#export CLDAQ_X11_INC_DIR=/usr/X11R6/include
#export CLDAQ_GTK_USE=1
#export CLDAQ_QT_USE=1
#export CLDAQ_QT_BASE_DIR=/usr/lib/qt-2.3.1
#export CLDAQ_QT_LIB_DIR=$CLDAQ_QT_BASE_DIR/lib
#export CLDAQ_QT_INC_DIR=$CLDAQ_QT_BASE_DIR/include
